@@ -16,55 +16,61 @@
  ***************************************************************************/
 
 #include "httphandler.h"
+#include "logfile.h"
+#include "utils.h"
+
 
 //Read header
 bool HTTPHandler::ReadHeader( string *headerT )
 {
 
     string::size_type position;
-    bool WrongHeader=false;
+    bool WrongHeader = false;
     int poscount = 0;
     ssize_t read;
-    string tempheader="";
+    string tempheader;
 
-    *headerT="";
+    *headerT = "";
 
-    if ( ( read = SocketHandler::Recv( &tempheader, false ) ) <= 0 )
+    if ( (read = SocketHandler::Recv( &tempheader, false, -1 )) <= 0 )
     {
         return false;
     }
 
-    //Maybe we should also look for \n\n (19.3 RFC 1945 - Tolerant Applications)
     while ( (position = tempheader.find ("\r\n\r\n")) == string::npos )
     {
-
+        //Maybe we should also look for \n\n (19.3 RFC 1945 - Tolerant Applications)
         if ( (position = tempheader.find ("\n\n")) != string::npos )
         {
-            WrongHeader=true;
+            WrongHeader = true;
             break;
         }
 
         //Header not yet found
         //Read and delete part of header containing no \r\n\r\n
-        SocketHandler::RecvLength(headerT, read );
-
-        poscount = poscount + read;
-
-        if( (read = SocketHandler::Recv( &tempheader, false )) <= 0)
+        if ( SocketHandler::RecvLength( headerT, read ) == false )
         {
             return false;
         }
 
-        //Connection Close by Peer
-        if ( read == 0 )
+        poscount += read;
+
+        //Too big header
+        if ( poscount > 20480 )
+        {
+            LogFile::ErrorMessage("Server sent too big header (>20kB)\n");
+            return false;
+        }
+
+        if ( (read = SocketHandler::Recv( &tempheader, false, -1 )) <= 0 )
         {
             return false;
         }
+
     }
 
-    //cout << tempheader << endl;
     //Read last part of header
-    if ( SocketHandler::RecvLength(headerT, position-poscount+2 ) == false )
+    if ( SocketHandler::RecvLength( headerT, position - poscount + 2 ) == false )
     {
         return false;
     }
@@ -77,79 +83,89 @@ bool HTTPHandler::ReadHeader( string *headerT )
             return false;
         }
     }
+
     return true;
 }
 
 
 //Split header to tokens
-bool HTTPHandler::AnalyseHeader(string *linesT, const char *delimitersT )
+int HTTPHandler::AnalyseHeader( string *linesT )
 {
 
-    string tempToken;
-
-    //delete tokens
+    //Delete header tokens
     tokens.clear();
 
-    //Clear Content Length
-    ContentLength=0;
-
     string::size_type lastposition = 0;
-    string::size_type length = linesT->length();
 
     //Do "Tolerant Applications" - RFC 1945 - Hypertext Transfer Protocol -- HTTP/1.0
-    while ( (lastposition = linesT->find ("\r",lastposition)) != string::npos )
+    while ( (lastposition = linesT->find( "\r", lastposition )) != string::npos )
     {
         linesT->replace( lastposition, 1, "" );
     }
 
     lastposition = 0;
-    length = linesT->length();
 
-    string::size_type position = linesT->find (delimitersT, 0);
-
-    if ( position == string::npos )
+    string::size_type length = linesT->length();
+    string::size_type position, positiontmp;
+    
+    if ( (position = linesT->find( "\n", 0 )) == string::npos )
     {
-        return false;
+        return -201;
     }
 
-    while (position != string::npos && lastposition != length)
+    int ret;
+    string tempToken, headerbase;
+
+    //Read first line with AnalyseFirstHeaderLine
+    bool First = true;
+
+    //Loop through headers
+    while ( position != string::npos && lastposition != length )
     {
-        tempToken = linesT->substr(lastposition, position - lastposition );
+        tempToken = linesT->substr( lastposition, position - lastposition );
 
         if ( (lastposition = tempToken.find_last_not_of("\t ")) != string::npos )
         {
-            tempToken = tempToken.substr(0,lastposition+1);
+            tempToken = tempToken.substr( 0, lastposition + 1 );
 
-            if( (lastposition = tempToken.find("Content-Length: ",0) ) == 0 )
+            if ( First == true )
             {
-                lastposition = lastposition + 16;
-                string Length = tempToken.substr(lastposition, tempToken.length() );
-                if (sscanf( Length.c_str(), "%lu",  &ContentLength) != 1)
+                //Analyse request header
+                if ( (ret = AnalyseFirstHeaderLine( &tempToken )) < 0 )
                 {
-                    ContentLength=0;
+                    return ret;
+                }
+                First = false;
+            }
+            else
+            {
+                if ( (positiontmp = tempToken.find(":")) != string::npos )
+                {
+                    headerbase = tempToken.substr(0, positiontmp + 1);
+
+                    //Make sure we have "Header:<SPACE>value"
+                    if ( (positiontmp = tempToken.find_first_not_of(" ", positiontmp + 1)) != string::npos )
+                    {
+                        tempToken = headerbase + " " + tempToken.substr(positiontmp);
+
+                        if ( (ret = AnalyseHeaderLine( &tempToken )) < 0 )
+                        {
+                            return ret;
+                        }
+                    }
+
                 }
             }
 
-            AnalyseHeaderLine( &tempToken );
-
-            tokens.push_back(  tempToken+"\r\n" );
+            //Add header to send queue
+            tokens.push_back( tempToken );
         }
 
         lastposition = position + 1;
-
-        position = linesT->find( delimitersT, lastposition);
+        position = linesT->find( "\n", lastposition );
     }
 
-    return true;
-}
-
-
-//Get Content Length
-unsigned long HTTPHandler::GetContentLength( )
-{
-
-    return ContentLength;
-
+    return 0;
 }
 
 
@@ -160,7 +176,7 @@ ssize_t HTTPHandler::ReadBodyPart( string* bodyT )
     *bodyT = "";
     ssize_t count;
 
-    if ( (count = SocketHandler::Recv( bodyT, true )) <= -1)
+    if ( (count = SocketHandler::Recv( bodyT, true, -1 )) < 0)
     {
         return -1;
     }
@@ -170,10 +186,20 @@ ssize_t HTTPHandler::ReadBodyPart( string* bodyT )
 
 
 //Send Header
-bool HTTPHandler::SendHeader( string* headerT )
+bool HTTPHandler::SendHeader( string header, bool ConnectionClose )
 {
+    if ( ProxyConnection ) header += "Proxy-";
 
-    if ( SocketHandler::Send( headerT ) == false )
+    if ( ConnectionClose )
+    {
+        header += "Connection: close\r\n\r\n";
+    }
+    else
+    {
+        header += "Connection: Keep-Alive\r\n\r\n";
+    }
+
+    if ( SocketHandler::Send( &header ) == false )
     {
         return false;
     }
@@ -182,6 +208,7 @@ bool HTTPHandler::SendHeader( string* headerT )
 }
 
 
+
 //Constructor
 HTTPHandler::HTTPHandler()
 {
