@@ -18,20 +18,10 @@
 #ifndef LOGFILE_H
 #define LOGFILE_H
 
-#include "default.h"
-
-//#include <sys/types.h>
-//#include <sys/stat.h>
-
-#include <fcntl.h>
-#include <stdarg.h>
-#include <unistd.h>
-
-#include <iostream>
+#include <string>
 
 using namespace std;
 
-
 class LogFile {
 
 private:
@@ -39,14 +29,12 @@ private:
 static int Error_fd;
 static int Access_fd;
 
-static void WriteDateAndTime( int fdT );
+static string GetDateAndTime();
 
 public:
 
-static bool InitLogFiles ( const char *AccessLogFileT, const char *ErrorLogFileT );
-
+static bool InitLogFiles( const char *AccessLogFileT, const char *ErrorLogFileT );
 static void AccessMessage( const char *formatT, ... );
-
 static void ErrorMessage( const char *formatT, ... );
    
 };
